@@ -2,7 +2,7 @@
  * gpe-conf
  *
  * Copyright (C) 2002  Pierre TARDY <tardyp@free.fr>
- *	             2003  Florian Boor <florian.boor@kernelconcepts.de>
+ *	             2003,2004  Florian Boor <florian.boor@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -218,6 +218,7 @@ Logread_Build_Objects (void)
 
   /* syslog box */	
   vbox = gtk_vbox_new(FALSE,gpe_get_boxspacing());
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), gpe_get_border ());
   tw = gtk_label_new(NULL);
   gtk_misc_set_alignment(GTK_MISC(tw),0.0,0.5);
   tstr = g_strdup_printf ("<b>%s</b>", _("System Log"));
@@ -227,6 +228,8 @@ Logread_Build_Objects (void)
 
   tc = gtk_scrolled_window_new(NULL,NULL);
   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(tc),GTK_SHADOW_IN);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(tc),
+		GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
   gtk_box_pack_start(GTK_BOX(vbox),tc,TRUE,TRUE,0);
 
   tw = gtk_text_view_new();	
@@ -240,6 +243,7 @@ Logread_Build_Objects (void)
   /* xsession-errors box */	
   
   vbox = gtk_vbox_new(FALSE,gpe_get_boxspacing());
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), gpe_get_border ());
   tw = gtk_label_new(NULL);
   gtk_misc_set_alignment(GTK_MISC(tw),0.0,0.5);
   tstr = g_strdup_printf ("<b>%s</b>", _("Session Log"));
