@@ -15,11 +15,6 @@
 #define	FALSE	0
 #endif
 
-typedef struct _irqCfg {
-  int	num;
-  char	*desc;
-} irqCfg;
-
 typedef struct _confCfg {
   int		nval;
   double	*val;
@@ -35,9 +30,6 @@ typedef struct _ipaq_conf_t {
   int		nConf;
   confCfg	*clist;
 
-  int		nIrq;
-  irqCfg	*ilist;
-
   int		blFD;
 } ipaq_conf_t;
 
@@ -56,7 +48,6 @@ void delConfigDbl(ipaq_conf_t *c, const char *name, double val);
 void check_configurable(ipaq_conf_t *c);
 ipaq_conf_t *load_ISconf(const char *fname);
 ipaq_conf_t *default_ISconf();
-void load_IRQs(ipaq_conf_t *c, const char *fname);
 int save_ISconf(ipaq_conf_t *c, const char *fname);
 
 void Sleep_Save ();
