@@ -2,7 +2,7 @@
  * gpe-conf
  *
  * Copyright (C) 2002  Pierre TARDY <tardyp@free.fr>
- *               2003  Florian Boor <florian.boor@kernelconcepts.de>
+ *               2003,2004  Florian Boor <florian.boor@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,8 +40,11 @@
 #define KEY_MATCHBOX "MATCHBOX/"
 #define KEY_THEME "Net/"
 #define KEY_GTK "Gtk/"
+#define CMD_XST PREFIX "/bin/xst"
+#define CMD_GCONF PREFIX "/bin/gconftool-2"
 
 static XSettingsClient *client;
+static gboolean use_xst, use_gconf;
 
 static struct
 {
@@ -103,18 +106,24 @@ static void select_font_popup (GtkWidget *parent_button);
 static void on_font_size_change(GtkSpinButton *spinbutton,GtkScrollType arg1);
 static GtkWidget *popup_menu_button_new (const gchar *stock_id);
 
+/* some init stuff related to external tools and libs */
+void
+init_tools(void)
+{
+	use_gconf = FALSE;
+	use_xst = FALSE;
+	
+	/* prefer gconf */
+	if (!access(CMD_GCONF,X_OK))
+		use_gconf = TRUE;
+	else
+		if (!access(CMD_XST,X_OK))
+			use_xst = TRUE;	
+}
 
 gboolean
 mbbg_parse_spec(MBDesktopBG *mbbg, char *spec)
 {
-  /*
-  img-stretched:filename>
-  img-tiled:<filename>
-  col-solid:<color definition>
-  col-gradient-vertical:<start color>,<end color>
-  col-gradient-horizontal:<start color>,<end color>
-  */
-
   XColor tmpxcol;
   int i, mapping_cnt, spec_offset = 0, type = 0;
   char *bg_def = NULL, *p = NULL;
@@ -694,8 +703,11 @@ on_matchbox_entry_changed (GtkWidget * menu, gpointer user_data)
 			    -1);
   if ((tn) && (strlen (tn)))
     {
-      system_printf ("xst write %s%s str %s", KEY_THEME, "ThemeName", tn);
-    }
+	  if (use_xst)
+		system_printf (CMD_XST " write %s%s str %s", KEY_THEME, "ThemeName", tn);
+/*	  if (use_gconf)
+#warning here		system_printf (CMD_GCONF " write %s%s str %s", KEY_THEME, "ThemeName", tn);
+*/    }
   if (tn)
     g_free (tn);
 }
@@ -926,6 +938,9 @@ Theme_Build_Objects ()
 
   csel = malloc (sizeof (tcsel));
   self.themename = NULL;
+  
+  init_tools();
+  
 /* ------------------------------------------------------------------------ */
 
   notebook  = gtk_notebook_new();
