@@ -3,7 +3,7 @@
  *              that either displays or sets the characteristics of
  *              one or more of the system's networking interfaces.
  *
- * Version:     $Id: interface.c,v 1.7 2004/01/09 14:49:18 florian Exp $
+ * Version:     $Id: interface.c,v 1.8 2004/06/17 15:20:59 florian Exp $
  *
  * Author:      Fred N. van Kempen, <waltje@uwalt.nl.mugnet.org>
  *              and others.  Copyright 1993 MicroWalt Corporation
@@ -1904,16 +1904,16 @@ char* if_to_infostr(struct interface *ptr)
 
 #if HAVE_AFINET
     if (ptr->has_ip) {
-	sprintf(tmp,_("Address:\t\t%s\n"),
+	sprintf(tmp,_("Address:\t%s\n"),
 	       ap->sprint(&ptr->addr, 1));
 	buffer = realloc(buffer,strlen(buffer)+strlen(tmp)+1);
 	strcat(buffer,tmp);
 	if (ptr->flags & IFF_POINTOPOINT) {
-	    sprintf(tmp,_("P-t-P:\t\t%s\n"), ap->sprint(&ptr->dstaddr, 1));
+	    sprintf(tmp,_("P-t-P:\t%s\n"), ap->sprint(&ptr->dstaddr, 1));
 		buffer = realloc(buffer,strlen(buffer)+strlen(tmp)+1);
 		strcat(buffer,tmp);
 	}
-	sprintf(tmp,_("Netmask:\t\t%s\n"), ap->sprint(&ptr->netmask, 1));
+	sprintf(tmp,_("Netmask:\t%s\n"), ap->sprint(&ptr->netmask, 1));
 	buffer = realloc(buffer,strlen(buffer)+strlen(tmp)+1);
 	strcat(buffer,tmp);
 	if (ptr->flags & IFF_BROADCAST) {
